@@ -14,8 +14,6 @@ import time
 import pyspark.sql.functions as F
 
 
-from pyspark.sql import Window
-
 from jklwcs.table import (
     _WIFI_STABLE_LOCALTION_TABLE,
     _WIFI_CONNECTED__LOCATION_TABLE,
@@ -57,12 +55,12 @@ class SelectUuid(object):
         employee_days=None,
         stay_min=None,
         result_name=None,
-        result_path=M_CROWD_PACK_RESULT_PATH,
-        temp_result=M_CROWD_PACK_TEMP_PATH,
-        arrvied_table=POI_ARRIVED_LOCATION_TABLE,
-        leave_table=POI_LEAVE_EVENT_TABLE,
-        poi_table=POI_TABLE,
-        poi_categories_table=POI_CATEGOIRES_TABLE,
+        result_path=_M_CROWD_PACK_RESULT_PATH,
+        temp_result=_M_CROWD_PACK_TEMP_PATH,
+        arrvied_table=_POI_ARRIVED_LOCATION_TABLE,
+        leave_table=_POI_LEAVE_EVENT_TABLE,
+        poi_table=_POI_TABLE,
+        poi_categories_table=_POI_CATEGOIRES_TABLE,
     ):
         """
         根据指定poi_id列表和时间范围查询uuid人群包,M1
@@ -80,25 +78,25 @@ class SelectUuid(object):
         :param poi_categories_table: poi分类表
         :return:dataframe,[UUID，POIID，POI名称，开始时间，结束时间，驻留时长，开始小时，周几，对应节假日，POI一二三级分类]
         """
-        logger = get_logger(result_name)
+        logger = _get_logger(result_name)
         date_range = pandas.date_range(start=date_list[0], end=date_list[1]).format()
 
         # 查询poi分类表和poi属性表,创建poi视图
-        df_categories = spark_1.sql(f"""select c_id,c_name from {poi_categories_table}""").toPandas()
+        df_categories = _spark.sql(f"""select c_id,c_name from {poi_categories_table}""").toPandas()
         c_id_categories_map = str({c_id: c_name for c_id, c_name in zip(df_categories.c_id, df_categories.c_name)})
         if len(poi_id_list) > 1:
-            df_poi = spark_1.sql(
+            df_poi = _spark.sql(
                 f"""select p_id,p_name,p_encryption_id,p_category_list from {poi_table} where p_id in {tuple(poi_id_list)}""")
         else:
-            df_poi = spark_1.sql(
+            df_poi = _spark.sql(
                 f"""select p_id,p_name,p_encryption_id,p_category_list from {poi_table} where p_id={poi_id_list[0]}""")
         df_poi \
             .withColumn('fisrt_c_name',
-                        F.split(get_category(F.col('p_category_list'), F.lit(c_id_categories_map)), '_')[0]) \
+                        F.split(_get_category(F.col('p_category_list'), F.lit(c_id_categories_map)), '_')[0]) \
             .withColumn('second_c_name',
-                        F.split(get_category(F.col('p_category_list'), F.lit(c_id_categories_map)), '_')[1]) \
+                        F.split(_get_category(F.col('p_category_list'), F.lit(c_id_categories_map)), '_')[1]) \
             .withColumn('third_c_name',
-                        F.split(get_category(F.col('p_category_list'), F.lit(c_id_categories_map)), '_')[2]) \
+                        F.split(_get_category(F.col('p_category_list'), F.lit(c_id_categories_map)), '_')[2]) \
             .select('p_id', 'p_name', 'p_encryption_id', 'fisrt_c_name', 'second_c_name', 'third_c_name') \
             .createOrReplaceTempView('poi_view')
 
@@ -122,7 +120,7 @@ class SelectUuid(object):
                 inner join poi_view b
                 on a.poi_id = b.p_id
                 """
-            spark_1 \
+            _spark \
                 .sql(sql_arrive) \
                 .drop_duplicates(subset=['uuid', 'poi_id', 'date_str', 'num']) \
                 .select("uuid", "poi_id", "poi_name", "date_str", "timestamp", 'fisrt_c_name', 'second_c_name',
@@ -143,7 +141,7 @@ class SelectUuid(object):
                 inner join poi_view b
                 on a.poi_id=b.p_encryption_id
                 """
-            spark_1 \
+            _spark \
                 .sql(sql_leave) \
                 .drop_duplicates(subset=['uuid', 'poi_id', 'date_str', 'num']) \
                 .select("uuid", "poi_id", "poi_name", "date_str", "timestamp", 'fisrt_c_name', 'second_c_name',
@@ -163,7 +161,7 @@ class SelectUuid(object):
                 and a.date_str = b.date_str
                 and a.timestamp < b.timestamp
             """
-            spark_1 \
+            _spark \
                 .sql(sql_arrive_leave) \
                 .withColumn('stay_min', F.round((F.col('end_time') - F.col('start_time')) / 1000 / 60, 4)) \
                 .withColumn('start_hour', F.hour('start_time_format')) \
@@ -176,15 +174,15 @@ class SelectUuid(object):
                 .parquet(temp_result + result_name)
             logger.info(f'M1 select task : name:{result_name},date:{date},spend:{time.time() - start_time}s')
 
-        df_arrive_levae = spark_1.read.option("header", "true").parquet(temp_result + result_name)
+        df_arrive_levae = _spark.read.option("header", "true").parquet(temp_result + result_name)
         logger.info('M1 filter task ...')
         # 过滤
         if business_hours:
-            business_hours_list = tran_business_hours(business_hours)
+            business_hours_list = _tran_business_hours(business_hours)
             df_arrive_levae = df_arrive_levae[F.col('start_hour').isin(business_hours_list)]
 
         if non_business_hours:
-            non_business_hours_list = tran_business_hours(non_business_hours)
+            non_business_hours_list = _tran_business_hours(non_business_hours)
             df_arrive_levae = df_arrive_levae[F.col('start_hour').isin(non_business_hours_list) == False]
 
         if employee_days:
